@@ -82,7 +82,7 @@ typedef struct _VipsEmbed {
 	VipsImage *in;
 
 	VipsExtend extend;
-	VipsArea *background;
+	VipsArrayDouble *background;
 	int x;
 	int y;
 	int width;
@@ -224,7 +224,7 @@ vips_embed_gen( VipsRegion *or, void *seq, void *a, void *b, gboolean *stop )
 	VipsEmbed *embed = (VipsEmbed *) b;
 	VipsRect *r = &or->valid;
 
-	Rect ovl;
+	VipsRect ovl;
 	int i;
 	VipsPel *p;
 	int plsk;
@@ -362,7 +362,8 @@ vips_embed_build( VipsObject *object )
 
 	if( !(embed->ink = vips__vector_to_ink( 
 		class->nickname, embed->in,
-		embed->background->data, NULL, embed->background->n )) )
+		VIPS_AREA( embed->background )->data, NULL, 
+		VIPS_AREA( embed->background )->n )) )
 		return( -1 );
 
 	if( !vips_object_argument_isset( object, "extend" ) &&
@@ -614,9 +615,7 @@ static void
 vips_embed_init( VipsEmbed *embed )
 {
 	embed->extend = VIPS_EXTEND_BLACK;
-	embed->background = 
-		vips_area_new_array( G_TYPE_DOUBLE, sizeof( double ), 1 ); 
-	((double *) (embed->background->data))[0] = 0;
+	embed->background = vips_array_double_newv( 1, 0.0 );
 }
 
 /**
@@ -631,8 +630,8 @@ vips_embed_init( VipsEmbed *embed )
  *
  * Optional arguments:
  *
- * @extend: how to generate the edge pixels (default: black)
- * @background: colour for edge pixels
+ * @extend: #VipsExtend to generate the edge pixels (default: black)
+ * @background: #VipsArrayDouble colour for edge pixels
  *
  * The opposite of vips_extract_area(): embed @in within an image of size 
  * @width by @height at position @x, @y.  @extend
