@@ -169,7 +169,7 @@ vips_insert_gen( VipsRegion *or, void *seq, void *a, void *b, gboolean *stop )
 	VipsRect *r = &or->valid;
 	VipsInsert *insert = (VipsInsert *) b; 
 
-	Rect ovl;
+	VipsRect ovl;
 
 	/* Does the rect we have been asked for fall entirely inside the
 	 * sub-image?
@@ -304,7 +304,7 @@ vips__ink_to_vector( const char *domain, VipsImage *im, VipsPel *ink, int *n )
 
 	/* Wrap a VipsImage around ink.
 	 */
-	t[0] = vips_image_new_from_memory( ink, 
+	t[0] = vips_image_new_from_memory( ink, VIPS_IMAGE_SIZEOF_PEL( im ),
 		1, 1, VIPS_IMAGE_SIZEOF_PEL( im ), VIPS_FORMAT_UCHAR );
 	if( vips_copy( t[0], &t[1], 
 		"bands", im->Bands, 
@@ -422,7 +422,8 @@ vips_insert_build( VipsObject *object )
 
 	if( !(insert->ink = vips__vector_to_ink( 
 		class->nickname, conversion->out,
-		insert->background->data, NULL, insert->background->n )) )
+		(double *) VIPS_ARRAY_ADDR( insert->background, 0 ), NULL, 
+		VIPS_AREA( insert->background )->n )) )
 		return( -1 );
 
 	if( vips_image_generate( conversion->out,
@@ -503,9 +504,7 @@ vips_insert_init( VipsInsert *insert )
 {
 	/* Init our instance fields.
 	 */
-	insert->background = 
-		vips_area_new_array( G_TYPE_DOUBLE, sizeof( double ), 1 ); 
-	((double *) (insert->background->data))[0] = 0.0;
+	insert->background = vips_array_double_newv( 1, 0.0 );
 }
 
 /**
@@ -540,7 +539,7 @@ vips_insert_init( VipsInsert *insert )
  *
  * The two input images are cast up to the smallest common type (see table 
  * Smallest common format in 
- * <link linkend="VIPS-arithmetic">arithmetic</link>).
+ * <link linkend="libvips-arithmetic">arithmetic</link>).
  *
  * See also: vips_join(), vips_embed(), vips_extract_area().
  *
