@@ -251,7 +251,7 @@ vips_foreign_save_jpeg_buffer_build( VipsObject *object )
 
 	void *obuf;
 	size_t olen;
-	VipsArea *area;
+	VipsBlob *blob;
 
 	if( VIPS_OBJECT_CLASS( vips_foreign_save_jpeg_buffer_parent_class )->
 		build( object ) )
@@ -262,9 +262,9 @@ vips_foreign_save_jpeg_buffer_build( VipsObject *object )
 		jpeg->interlace, save->strip, jpeg->no_subsample ) )
 		return( -1 );
 
-	area = vips_area_new_blob( (VipsCallbackFn) vips_free, obuf, olen );
-	g_object_set( file, "buffer", area, NULL );
-	vips_area_unref( area );
+	blob = vips_blob_new( (VipsCallbackFn) vips_free, obuf, olen );
+	g_object_set( file, "buffer", blob, NULL );
+	vips_area_unref( VIPS_AREA( blob ) );
 
 	return( 0 );
 }
