@@ -40,6 +40,8 @@
  * 	- turn into a set of read fns ready to be called from a class
  * 11/6/13
  * 	- add @all_frames option, off by default
+ * 4/12/14 Lovell
+ * 	- add @density option 
  */
 
 /*
@@ -141,7 +143,8 @@ read_destroy( VipsImage *im, Read *read )
 }
 
 static Read *
-read_new( const char *filename, VipsImage *im, gboolean all_frames )
+read_new( const char *filename, VipsImage *im, gboolean all_frames,
+	const char *density )
 {
 	Read *read;
 	static int inited = 0;
@@ -175,6 +178,10 @@ read_new( const char *filename, VipsImage *im, gboolean all_frames )
 
 	vips_strncpy( read->image_info->filename, filename, MaxTextExtent );
 
+	/* Canvas resolution for rendering vector formats like SVG.
+	 */
+	VIPS_SETSTR( read->image_info->density, density );
+
 #ifdef DEBUG
 	printf( "magick2vips: read_new: %s\n", read->filename );
 #endif /*DEBUG*/
@@ -647,7 +654,8 @@ magick_fill_region( VipsRegion *out,
 }
 
 int
-vips__magick_read( const char *filename, VipsImage *out, gboolean all_frames )
+vips__magick_read( const char *filename, VipsImage *out, gboolean all_frames,
+	const char *density )
 {
 	Read *read;
 
@@ -655,7 +663,7 @@ vips__magick_read( const char *filename, VipsImage *out, gboolean all_frames )
 	printf( "magick2vips: vips__magick_read: %s\n", filename );
 #endif /*DEBUG*/
 
-	if( !(read = read_new( filename, out, all_frames )) )
+	if( !(read = read_new( filename, out, all_frames, density )) )
 		return( -1 );
 
 #ifdef HAVE_SETIMAGEOPTION
@@ -697,7 +705,7 @@ vips__magick_read( const char *filename, VipsImage *out, gboolean all_frames )
  */
 int
 vips__magick_read_header( const char *filename, VipsImage *im, 
-	gboolean all_frames )
+	gboolean all_frames, const char *density )
 {
 	Read *read;
 
@@ -705,7 +713,7 @@ vips__magick_read_header( const char *filename, VipsImage *im,
 	printf( "vips__magick_read_header: %s\n", filename );
 #endif /*DEBUG*/
 
-	if( !(read = read_new( filename, im, all_frames )) )
+	if( !(read = read_new( filename, im, all_frames, density )) )
 		return( -1 );
 
 #ifdef DEBUG
