@@ -181,7 +181,7 @@ typedef struct {
         ErrorManager eman;
 	JSAMPROW *row_pointer;
 	char *profile_bytes;
-	unsigned int profile_length;
+	size_t profile_length;
 	VipsImage *inverted;
 } Write;
 
@@ -836,7 +836,7 @@ write_profile_meta( Write *write )
 }
 
 static int
-write_jpeg_block( REGION *region, Rect *area, void *a )
+write_jpeg_block( VipsRegion *region, VipsRect *area, void *a )
 {
 	Write *write = (Write *) a;
 	int i;
