@@ -50,6 +50,8 @@
  * 	- more robust error handling from libpng
  * 9/8/14
  * 	- don't check profiles, helps with libpng >=1.6.11
+ * 27/10/14 Lovell
+ * 	- add @filter option 
  */
 
 /*
@@ -81,6 +83,7 @@
 
 /*
 #define DEBUG
+#define VIPS_DEBUG
  */
 
 #ifdef HAVE_CONFIG_H
@@ -337,15 +340,15 @@ png2vips_header( Read *read, VipsImage *out )
 	/* If we're an INTEL byte order machine and this is 16bits, we need
 	 * to swap bytes.
 	 */
-	if( bit_depth > 8 && !vips_amiMSBfirst() )
+	if( bit_depth > 8 && 
+		!vips_amiMSBfirst() )
 		png_set_swap( read->pPng );
 
-	/* Get resolution. I'm not sure what we should do for UNKNOWN, since
-	 * vips is always pixels/mm.
+	/* Get resolution. Default to 72 pixels per inch, the usual png value. 
 	 */
 	unit_type = PNG_RESOLUTION_METER;
-	res_x = 1000;
-	res_y = 1000;
+	res_x = (72 / 2.54 * 100);
+	res_y = (72 / 2.54 * 100);
 	png_get_pHYs( read->pPng, read->pInfo, &res_x, &res_y, &unit_type );
 	switch( unit_type ) {
 	case PNG_RESOLUTION_METER:
@@ -754,7 +757,7 @@ write_new( VipsImage *in )
 }
 
 static int
-write_png_block( VipsRegion *region, Rect *area, void *a )
+write_png_block( VipsRegion *region, VipsRect *area, void *a )
 {
 	Write *write = (Write *) a;
 
@@ -783,7 +786,8 @@ write_png_block( VipsRegion *region, Rect *area, void *a )
 /* Write a VIPS image to PNG.
  */
 static int
-write_vips( Write *write, int compress, int interlace, const char *profile )
+write_vips( Write *write, int compress, int interlace, const char *profile,
+	VipsForeignPngFilter filter )
 {
 	VipsImage *in = write->in;
 
@@ -824,6 +828,10 @@ write_vips( Write *write, int compress, int interlace, const char *profile )
 	 */
 	png_set_compression_level( write->pPng, compress );
 
+	/* Set row filter.
+	 */
+	png_set_filter( write->pPng, 0, filter );
+
 	bit_depth = in->BandFmt == VIPS_FORMAT_UCHAR ? 8 : 16;
 
 	switch( in->Bands ) {
@@ -833,11 +841,9 @@ write_vips( Write *write, int compress, int interlace, const char *profile )
 	case 4: color_type = PNG_COLOR_TYPE_RGB_ALPHA; break;
 
 	default:
-		g_assert( 0 );
-
-		/* Keep -Wall happy.
-		 */
-		return( 0 );
+		vips_error( "vips2png", 
+			_( "can't save %d band image as png" ), in->Bands );
+		return( -1 );
 	}
 
 	interlace_type = interlace ? PNG_INTERLACE_ADAM7 : PNG_INTERLACE_NONE;
@@ -857,22 +863,20 @@ write_vips( Write *write, int compress, int interlace, const char *profile )
 	if( profile ) {
 		if( strcmp( profile, "none" ) != 0 ) { 
 			void *data;
-			unsigned int length;
+			size_t length;
 
-			if( !(data = 
-				vips__file_read_name( profile, VIPS_ICC_DIR, 
-				&length )) ) 
+			if( !(data = vips__file_read_name( profile, 
+				VIPS_ICC_DIR, &length )) ) 
 				return( -1 );
 
 #ifdef DEBUG
 			printf( "write_vips: "
-				"attaching %d bytes of ICC profile\n",
+				"attaching %zd bytes of ICC profile\n",
 				length );
 #endif /*DEBUG*/
 
 			png_set_iCCP( write->pPng, write->pInfo, "icc", 
-				PNG_COMPRESSION_TYPE_BASE, 
-				data, length );
+				PNG_COMPRESSION_TYPE_BASE, data, length );
 		}
 	}
 	else if( vips_image_get_typeof( in, VIPS_META_ICC_NAME ) ) {
@@ -923,7 +927,8 @@ write_vips( Write *write, int compress, int interlace, const char *profile )
 
 int
 vips__png_write( VipsImage *in, const char *filename, 
-	int compress, int interlace, const char *profile )
+	int compress, int interlace, const char *profile,
+	VipsForeignPngFilter filter )
 {
 	Write *write;
 
@@ -942,7 +947,7 @@ vips__png_write( VipsImage *in, const char *filename,
 
 	/* Convert it!
 	 */
-	if( write_vips( write, compress, interlace, profile ) ) {
+	if( write_vips( write, compress, interlace, profile, filter ) ) {
 		vips_error( "vips2png", 
 			_( "unable to write \"%s\"" ), filename );
 
@@ -1029,7 +1034,7 @@ user_write_data( png_structp png_ptr, png_bytep data, png_size_t length )
 int
 vips__png_write_buf( VipsImage *in, 
 	void **obuf, size_t *olen, int compression, int interlace,
-	const char *profile )
+	const char *profile, VipsForeignPngFilter filter )
 {
 	WriteBuf *wbuf;
 	Write *write;
@@ -1045,7 +1050,7 @@ vips__png_write_buf( VipsImage *in,
 
 	/* Convert it!
 	 */
-	if( write_vips( write, compression, interlace, profile ) ) {
+	if( write_vips( write, compression, interlace, profile, filter ) ) {
 		write_buf_free( wbuf );
 		vips_error( "vips2png", 
 			"%s", _( "unable to write to buffer" ) );
