@@ -614,13 +614,13 @@ vips_image_get_mode( const VipsImage *image )
  * Returns: the scale.
  */
 double
-vips_image_get_scale( const VipsImage *array )
+vips_image_get_scale( const VipsImage *image )
 {
 	double scale;
 
 	scale = 1.0;
-	if( vips_image_get_typeof( array, "scale" ) ) 
-		vips_image_get_double( array, "scale", &scale );
+	if( vips_image_get_typeof( image, "scale" ) ) 
+		vips_image_get_double( image, "scale", &scale );
 
 	return( scale );
 }
@@ -635,13 +635,13 @@ vips_image_get_scale( const VipsImage *array )
  * Returns: the offset.
  */
 double
-vips_image_get_offset( const VipsImage *array )
+vips_image_get_offset( const VipsImage *image )
 {
 	double offset;
 
 	offset = 0.0;
-	if( vips_image_get_typeof( array, "offset" ) ) 
-		vips_image_get_double( array, "offset", &offset );
+	if( vips_image_get_typeof( image, "offset" ) ) 
+		vips_image_get_double( image, "offset", &offset );
 
 	return( offset );
 }
@@ -656,9 +656,9 @@ vips_image_get_offset( const VipsImage *array )
  *
  * See also: vips_image_wio_input().
  *
- * Returns: a pointer to pixel data, if possible.
+ * Returns: (transfer none): a pointer to pixel data, if possible.
  */
-void *
+const void *
 vips_image_get_data( VipsImage *image )
 {
 	if( vips_image_wio_input( image ) )
@@ -838,7 +838,7 @@ vips_image_set( VipsImage *image, const char *field, GValue *value )
  * vips_image_get:
  * @image: image to get the field from from
  * @field: the name to give the metadata
- * @value_copy: the %GValue is copied into this
+ * @value_copy: (transfer full) (out caller-allocates): the %GValue is copied into this
  *
  * Fill @value_copy with a copy of the header field. @value_copy must be zeroed 
  * but uninitialised.
@@ -872,7 +872,7 @@ vips_image_set( VipsImage *image, const char *field, GValue *value )
  *
  * See also: vips_image_get_typeof(), vips_image_get_double().
  *
- * Returns: 0 on success, -1 otherwise.
+ * Returns: (skip): 0 on success, -1 otherwise.
  */
 int
 vips_image_get( const VipsImage *image, const char *field, GValue *value_copy )
@@ -1018,7 +1018,7 @@ vips_image_map_fn( VipsMeta *meta, VipsImageMapFn fn, void *a )
 /**
  * vips_image_map: 
  * @image: image to map over
- * @fn: function to call for each header field
+ * @fn: (scope call): function to call for each header field
  * @a: user data for function
  *
  * This function calls @fn for every header field, including every item of 
@@ -1029,7 +1029,7 @@ vips_image_map_fn( VipsMeta *meta, VipsImageMapFn fn, void *a )
  *
  * See also: vips_image_get_typeof(), vips_image_get().
  *
- * Returns: %NULL on success, the failing pointer otherwise.
+ * Returns: (transfer none): %NULL on success, the failing pointer otherwise.
  */
 void *
 vips_image_map( VipsImage *image, VipsImageMapFn fn, void *a )
