@@ -1675,7 +1675,7 @@ vips_image_temp_name( void )
  * vips_image_write_line(). Write a whole image to another image with
  * vips_image_write(). 
  *
- * Returns: the new #VipsImage, or %NULL on error.
+ * Returns: (transfer full): the new #VipsImage, or %NULL on error.
  */
 VipsImage *
 vips_image_new( void )
@@ -1728,7 +1728,7 @@ vips_image_new_mode( const char *filename, const char *mode )
  *
  * See also: vips_image_new().
  *
- * Returns: the new #VipsImage, or %NULL on error.
+ * Returns: (transfer full): the new #VipsImage, or %NULL on error.
  */
 VipsImage *
 vips_image_new_memory( void )
@@ -1736,6 +1736,22 @@ vips_image_new_memory( void )
 	return( vips_image_new_mode( vips_image_temp_name(), "t" ) );
 }
 
+/**
+ * vips_image_memory:
+ *
+ * A renamed vips_image_new_memory() ... Some gobject binding systems do not 
+ * like more than one _new() method.
+ *
+ * See also: vips_image_new_memory().
+ *
+ * Returns: (transfer full): the new #VipsImage, or %NULL on error.
+ */
+VipsImage *
+vips_image_memory( void )
+{
+	return( vips_image_new_memory() ); 
+}
+
 /**
  * vips_filename_get_filename:
  * @vips_filename: a filename including a set of options
