@@ -1478,8 +1478,10 @@ vips_object_real_summary( VipsObject *object, VipsBuf *buf )
 static void
 vips_object_real_dump( VipsObject *object, VipsBuf *buf )
 {
-	vips_buf_appendf( buf, " %s (%p)", 
-		G_OBJECT_TYPE_NAME( object ), object );
+	vips_buf_appendf( buf, " %s (%p) count=%d", 
+		G_OBJECT_TYPE_NAME( object ), 
+		object, 
+		G_OBJECT( object )->ref_count );
 
 	if( object->local_memory )
 		vips_buf_appendf( buf, " %zd bytes", object->local_memory ); 
@@ -2903,10 +2905,11 @@ vips_object_print_all_cb( VipsObject *object, int *n )
 		*n, G_OBJECT_TYPE_NAME( object ), object );
 	if( object->local_memory )
 		fprintf( stderr, " %zd bytes", object->local_memory ); 
+	fprintf( stderr, ", count=%d", G_OBJECT( object )->ref_count ); 
 	fprintf( stderr, "\n" ); 
 
 	vips_object_summary_class( class, &buf );
-	vips_buf_appends( &buf, " " );
+	vips_buf_appends( &buf, ", " );
 	vips_object_summary( object, &buf ); 
 	fprintf( stderr, "%s\n", vips_buf_all( &buf ) );
 
